"""
Top-level package for `scilaunch`.

`scilaunch` should be run via the command line:

    scilaunch PARENT/DIR


Alternatively, use Python's `-m` flag:

    python -m scilaunch.main PARENT/DIR

Follow the instructions in the terminal to set up the research project.
"""
__author__ = """Simon M. Hofmann"""
__version__ = "0.2.1"
